Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/__init__.py | 3 | 0 | 0 | 100%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/base.py | 118 | 36 | 0 | 69%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/cli.py | 24 | 24 | 0 | 0%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/commands/__init__.py | 0 | 0 | 0 | 100%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/commands/from_yaml.py | 30 | 30 | 0 | 0%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/defaults.py | 23 | 0 | 0 | 100%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/exceptions.py | 68 | 40 | 0 | 41%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/helpers/__init__.py | 0 | 0 | 0 | 100%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/helpers/elastic_api.py | 383 | 128 | 0 | 67%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/helpers/steps.py | 468 | 137 | 0 | 71%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/helpers/utils.py | 206 | 59 | 0 | 71%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/job.py | 217 | 61 | 0 | 72%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/redacters/__init__.py | 0 | 0 | 0 | 100%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/redacters/index.py | 126 | 42 | 0 | 67%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/redacters/snapshot.py | 80 | 11 | 0 | 86%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/redacters/steps.py | 54 | 3 | 0 | 94%
/Users/buh/.pyenv/versions/3.12.2/envs/pii/lib/python3.12/site-packages/es_pii_tool/trackables.py | 197 | 42 | 0 | 79%
Total | 1997 | 613 | 0 | 69%

No items found using the specified filter.